# © 2016-2019 Resurface Labs Inc.


class HttpMessage(object):

    @staticmethod
    def build():
        message = []

        return message

    @staticmethod
    def _append_request_headers(message, request):
        pass

    @staticmethod
    def _append_request_params(message, request):
        pass

    @staticmethod
    def _append_response_headers(message, response):
        pass

    @staticmethod
    def _append_value(message, key, value=None):
        pass
